developerscripttools
====================

.. automodule:: abjad.tools.developerscripttools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript
      ~abjad.tools.developerscripttools.DirectoryScript.DirectoryScript

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.developerscripttools.AbjDevScript.AbjDevScript
      ~abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript
      ~abjad.tools.developerscripttools.BuildApiScript.BuildApiScript
      ~abjad.tools.developerscripttools.CleanScript.CleanScript
      ~abjad.tools.developerscripttools.CountLinewidthsScript.CountLinewidthsScript
      ~abjad.tools.developerscripttools.CountToolsScript.CountToolsScript
      ~abjad.tools.developerscripttools.MakeNewClassTemplateScript.MakeNewClassTemplateScript
      ~abjad.tools.developerscripttools.MakeNewFunctionTemplateScript.MakeNewFunctionTemplateScript
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript
      ~abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript
      ~abjad.tools.developerscripttools.ReplaceInFilesScript.ReplaceInFilesScript
      ~abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript
      ~abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.developerscripttools.get_developer_script_classes.get_developer_script_classes
      ~abjad.tools.developerscripttools.run_abjadbook.run_abjadbook
      ~abjad.tools.developerscripttools.run_ajv.run_ajv
